@@ -1,5 +1,6 @@
 from .csv_import import csv_import
 from .csv_export import csv_export
 from .truncate import truncate
+from .move import move
 
-__all__ = ["csv_import", "csv_export", "truncate"]
+__all__ = ["csv_import", "csv_export", "truncate", "move"]
